#-----------------------------------------------------------------------------
# Copyright (c) 2014-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------

import os
from PyInstaller.utils.hooks.qt import add_qt5_dependencies, \
    pyside2_library_info
from PyInstaller.utils.hooks import get_module_file_attribute, \
    collect_system_data_files
from PyInstaller.depend.bindepend import getImports
import PyInstaller.compat as compat


def get_relative_path_if_possible(actual, possible_prefix):
    possible_relative_path = os.path.relpath(actual, possible_prefix)
    if possible_relative_path.startswith(os.pardir):
        return actual
    else:
        return possible_relative_path


def prefix_with_path(prefix_path, *paths):
    if compat.is_py2:
        return os.path.join(*(prefix_path + list(paths)))
    else:
        return os.path.join(*prefix_path, *paths)  # noqa: E999


# Ensure PySide2 is importable before adding info depending on it.
if pyside2_library_info.version:
    hiddenimports, binaries, datas = add_qt5_dependencies(__file__)

    # Include the web engine process, translations, and resources.
    # According to https://bugreports.qt.io/browse/PYSIDE-642
    # there's no subdir for windows
    if compat.is_win:
        rel_data_path = ['PySide2']
    else:
        rel_data_path = ['PySide2', 'Qt']

    pyside2_locations = pyside2_library_info.location
    if compat.is_darwin:
        # This is based on the layout of the Mac wheel from PyPi.
        data_path = pyside2_locations['DataPath']
        libraries = ['QtCore', 'QtWebEngineCore', 'QtQuick', 'QtQml',
                     'QtNetwork', 'QtGui', 'QtWebChannel',
                     'QtPositioning']
        for i in libraries:
            datas += collect_system_data_files(
                os.path.join(data_path, 'lib', i + '.framework'),
                prefix_with_path(rel_data_path, 'lib'), True)
        datas += [(os.path.join(data_path, 'lib', 'QtWebEngineCore.framework',
                                'Resources'), os.curdir)]
    else:
        locales = 'qtwebengine_locales'
        resources = 'resources'
        datas += [
            # Gather translations needed by Chromium.
            (os.path.join(pyside2_locations['TranslationsPath'], locales),
             prefix_with_path(rel_data_path, 'translations', locales)),
            # Per the `docs
            # <https://doc.qt.io/qt-5.10/qtwebengine-deploying.html#deploying-resources>`_,
            # ``DataPath`` is the base directory for ``resources``.
            #
            (os.path.join(pyside2_locations['DataPath'], resources),
             prefix_with_path(rel_data_path, resources)),
            # Include the webengine process. The ``LibraryExecutablesPath``
            # is only valid on Windows and Linux.
            #
            (os.path.join(pyside2_locations['LibraryExecutablesPath'],
                          'QtWebEngineProcess*'),
             prefix_with_path(rel_data_path, get_relative_path_if_possible(
                 pyside2_locations['LibraryExecutablesPath'],
                 pyside2_locations['PrefixPath'] + '/')))
        ]

    # Add Linux-specific libraries.
    if compat.is_linux:
        # The automatic library detection fails for `NSS
        # <https://packages.ubuntu.com/search?keywords=libnss3>`_, which is
        # used by QtWebEngine. In some distributions, the ``libnss``
        # supporting libraries are stored in a subdirectory ``nss``. Since
        # ``libnss`` is not statically linked to these, but dynamically loads
        # them, we need to search for and add them.
        #
        # First, get all libraries linked to ``PyQt5.QtWebEngineWidgets``.
        for imp in getImports(
                get_module_file_attribute('PySide2.QtWebEngineWidgets')):
            # Look for ``libnss3.so``.
            if os.path.basename(imp).startswith('libnss3.so'):
                # Find the location of NSS: given a ``/path/to/libnss.so``,
                # add ``/path/to/nss/*.so`` to get the missing NSS libraries.
                nss_subdir = os.path.join(os.path.dirname(imp), 'nss')
                if os.path.exists(nss_subdir):
                    binaries.append((os.path.join(nss_subdir, '*.so'), 'nss'))



#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------


"""
Hook for PyOpenGL 3.x versions from 3.0.0b6 up. Previous versions have a
plugin system based on pkg_resources which is problematic to handle correctly
under pyinstaller; 2.x versions used to run fine without hooks, so this one
shouldn't hurt.
"""


from PyInstaller.compat import is_win, is_darwin
from PyInstaller.utils.hooks import collect_data_files
from PyInstaller.utils.hooks import opengl_arrays_modules


# PlatformPlugin performs a conditional import based on os.name and
# sys.platform. PyInstaller misses this so let's add it ourselves...
if is_win:
    hiddenimports = ['OpenGL.platform.win32']
elif is_darwin:
    hiddenimports = ['OpenGL.platform.darwin']
# Use glx for other platforms (Linux, ...)
else:
    hiddenimports = ['OpenGL.platform.glx']


# Arrays modules are needed too.
hiddenimports += opengl_arrays_modules()


# PyOpenGL 3.x uses ctypes to load DLL libraries. PyOpenGL windows installer
# adds necessary dll files to 
#   DLL_DIRECTORY = os.path.join( os.path.dirname( OpenGL.__file__ ), 'DLLS')
# PyInstaller is not able to find these dlls. Just include them all as data
# files.
if is_win:
    datas = collect_data_files('OpenGL')



#! /usr/bin/env python
# encoding: utf-8
# WARNING! Do not edit! https://waf.io/book/index.html#_obtaining_the_waf_file

from waflib.Tools import ccroot,ar
from waflib.Configure import conf
@conf
def find_xlcxx(conf):
	cxx=conf.find_program(['xlc++_r','xlc++'],var='CXX')
	conf.get_xlc_version(cxx)
	conf.env.CXX_NAME='xlc++'
@conf
def xlcxx_common_flags(conf):
	v=conf.env
	v.CXX_SRC_F=[]
	v.CXX_TGT_F=['-c','-o']
	if not v.LINK_CXX:
		v.LINK_CXX=v.CXX
	v.CXXLNK_SRC_F=[]
	v.CXXLNK_TGT_F=['-o']
	v.CPPPATH_ST='-I%s'
	v.DEFINES_ST='-D%s'
	v.LIB_ST='-l%s'
	v.LIBPATH_ST='-L%s'
	v.STLIB_ST='-l%s'
	v.STLIBPATH_ST='-L%s'
	v.RPATH_ST='-Wl,-rpath,%s'
	v.SONAME_ST=[]
	v.SHLIB_MARKER=[]
	v.STLIB_MARKER=[]
	v.LINKFLAGS_cxxprogram=['-Wl,-brtl']
	v.cxxprogram_PATTERN='%s'
	v.CXXFLAGS_cxxshlib=['-fPIC']
	v.LINKFLAGS_cxxshlib=['-G','-Wl,-brtl,-bexpfull']
	v.cxxshlib_PATTERN='lib%s.so'
	v.LINKFLAGS_cxxstlib=[]
	v.cxxstlib_PATTERN='lib%s.a'
def configure(conf):
	conf.find_xlcxx()
	conf.find_ar()
	conf.xlcxx_common_flags()
	conf.cxx_load_tools()
	conf.cxx_add_flags()
	conf.link_add_flags()



#-----------------------------------------------------------------------------
# Copyright (c) 2005-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------
import os

from PyInstaller.utils.hooks import collect_system_data_files
from PyInstaller.utils.hooks.qt import pyqt5_library_info, get_qt_binaries

# Ensure PyQt5 is importable before adding info depending on it.
if pyqt5_library_info.version:
    hiddenimports = [
        # PyQt5.10 and earlier uses sip in an separate package;
        'sip',
        # PyQt5.11 and later provides SIP in a private package. Support both.
        'PyQt5.sip'
    ]

    # Collect the ``qt.conf`` file.
    datas = [x for x in
             collect_system_data_files(pyqt5_library_info.location['PrefixPath'],
                                       'PyQt5')
             if os.path.basename(x[0]) == 'qt.conf']

    # Collect required Qt binaries.
    binaries = get_qt_binaries(pyqt5_library_info)



#! /usr/bin/env python
# encoding: utf-8
# WARNING! Do not edit! https://waf.io/book/index.html#_obtaining_the_waf_file

from __future__ import with_statement
try:
	from xml.sax import make_parser
	from xml.sax.handler import ContentHandler
except ImportError:
	has_xml=False
	ContentHandler=object
else:
	has_xml=True
import os,sys,re
from waflib.Tools import cxx
from waflib import Build,Task,Utils,Options,Errors,Context
from waflib.TaskGen import feature,after_method,extension,before_method
from waflib.Configure import conf
from waflib import Logs
MOC_H=['.h','.hpp','.hxx','.hh']
EXT_RCC=['.qrc']
EXT_UI=['.ui']
EXT_QT5=['.cpp','.cc','.cxx','.C']
class qxx(Task.classes['cxx']):
	def __init__(self,*k,**kw):
		Task.Task.__init__(self,*k,**kw)
		self.moc_done=0
	def runnable_status(self):
		if self.moc_done:
			return Task.Task.runnable_status(self)
		else:
			for t in self.run_after:
				if not t.hasrun:
					return Task.ASK_LATER
			self.add_moc_tasks()
			return Task.Task.runnable_status(self)
	def create_moc_task(self,h_node,m_node):
		try:
			moc_cache=self.generator.bld.moc_cache
		except AttributeError:
			moc_cache=self.generator.bld.moc_cache={}
		try:
			return moc_cache[h_node]
		except KeyError:
			tsk=moc_cache[h_node]=Task.classes['moc'](env=self.env,generator=self.generator)
			tsk.set_inputs(h_node)
			tsk.set_outputs(m_node)
			tsk.env.append_unique('MOC_FLAGS','-i')
			if self.generator:
				self.generator.tasks.append(tsk)
			gen=self.generator.bld.producer
			gen.outstanding.append(tsk)
			gen.total+=1
			return tsk
		else:
			delattr(self,'cache_sig')
	def add_moc_tasks(self):
		node=self.inputs[0]
		bld=self.generator.bld
		if bld.is_install==Build.UNINSTALL:
			return
		try:
			self.signature()
		except KeyError:
			pass
		else:
			delattr(self,'cache_sig')
		include_nodes=[node.parent]+self.generator.includes_nodes
		moctasks=[]
		mocfiles=set()
		for d in bld.raw_deps.get(self.uid(),[]):
			if not d.endswith('.moc'):
				continue
			if d in mocfiles:
				continue
			mocfiles.add(d)
			h_node=None
			base2=d[:-4]
			prefix=node.name[:node.name.rfind('.')]
			if base2==prefix:
				h_node=node
			else:
				for x in include_nodes:
					for e in MOC_H:
						h_node=x.find_node(base2+e)
						if h_node:
							break
					else:
						continue
					break
			if h_node:
				m_node=h_node.change_ext('.moc')
			else:
				raise Errors.WafError('No source found for %r which is a moc file'%d)
			task=self.create_moc_task(h_node,m_node)
			moctasks.append(task)
		self.run_after.update(set(moctasks))
		self.moc_done=1
class trans_update(Task.Task):
	run_str='${QT_LUPDATE} ${SRC} -ts ${TGT}'
	color='BLUE'
class XMLHandler(ContentHandler):
	def __init__(self):
		ContentHandler.__init__(self)
		self.buf=[]
		self.files=[]
	def startElement(self,name,attrs):
		if name=='file':
			self.buf=[]
	def endElement(self,name):
		if name=='file':
			self.files.append(str(''.join(self.buf)))
	def characters(self,cars):
		self.buf.append(cars)
@extension(*EXT_RCC)
def create_rcc_task(self,node):
	rcnode=node.change_ext('_rc.%d.cpp'%self.idx)
	self.create_task('rcc',node,rcnode)
	cpptask=self.create_task('cxx',rcnode,rcnode.change_ext('.o'))
	try:
		self.compiled_tasks.append(cpptask)
	except AttributeError:
		self.compiled_tasks=[cpptask]
	return cpptask
@extension(*EXT_UI)
def create_uic_task(self,node):
	try:
		uic_cache=self.bld.uic_cache
	except AttributeError:
		uic_cache=self.bld.uic_cache={}
	if node not in uic_cache:
		uictask=uic_cache[node]=self.create_task('ui5',node)
		uictask.outputs=[node.parent.find_or_declare(self.env.ui_PATTERN%node.name[:-3])]
@extension('.ts')
def add_lang(self,node):
	self.lang=self.to_list(getattr(self,'lang',[]))+[node]
@feature('qt5')
@before_method('process_source')
def process_mocs(self):
	lst=self.to_nodes(getattr(self,'moc',[]))
	self.source=self.to_list(getattr(self,'source',[]))
	for x in lst:
		prefix=x.name[:x.name.rfind('.')]
		moc_target='moc_%s.%d.cpp'%(prefix,self.idx)
		moc_node=x.parent.find_or_declare(moc_target)
		self.source.append(moc_node)
		self.create_task('moc',x,moc_node)
@feature('qt5')
@after_method('apply_link')
def apply_qt5(self):
	if getattr(self,'lang',None):
		qmtasks=[]
		for x in self.to_list(self.lang):
			if isinstance(x,str):
				x=self.path.find_resource(x+'.ts')
			qmtasks.append(self.create_task('ts2qm',x,x.change_ext('.%d.qm'%self.idx)))
		if getattr(self,'update',None)and Options.options.trans_qt5:
			cxxnodes=[a.inputs[0]for a in self.compiled_tasks]+[a.inputs[0]for a in self.tasks if a.inputs and a.inputs[0].name.endswith('.ui')]
			for x in qmtasks:
				self.create_task('trans_update',cxxnodes,x.inputs)
		if getattr(self,'langname',None):
			qmnodes=[x.outputs[0]for x in qmtasks]
			rcnode=self.langname
			if isinstance(rcnode,str):
				rcnode=self.path.find_or_declare(rcnode+('.%d.qrc'%self.idx))
			t=self.create_task('qm2rcc',qmnodes,rcnode)
			k=create_rcc_task(self,t.outputs[0])
			self.link_task.inputs.append(k.outputs[0])
	lst=[]
	for flag in self.to_list(self.env.CXXFLAGS):
		if len(flag)<2:
			continue
		f=flag[0:2]
		if f in('-D','-I','/D','/I'):
			if(f[0]=='/'):
				lst.append('-'+flag[1:])
			else:
				lst.append(flag)
	self.env.append_value('MOC_FLAGS',lst)
@extension(*EXT_QT5)
def cxx_hook(self,node):
	return self.create_compiled_task('qxx',node)
class rcc(Task.Task):
	color='BLUE'
	run_str='${QT_RCC} -name ${tsk.rcname()} ${SRC[0].abspath()} ${RCC_ST} -o ${TGT}'
	ext_out=['.h']
	def rcname(self):
		return os.path.splitext(self.inputs[0].name)[0]
	def scan(self):
		if not has_xml:
			Logs.error('No xml.sax support was found, rcc dependencies will be incomplete!')
			return([],[])
		parser=make_parser()
		curHandler=XMLHandler()
		parser.setContentHandler(curHandler)
		with open(self.inputs[0].abspath(),'r')as f:
			parser.parse(f)
		nodes=[]
		names=[]
		root=self.inputs[0].parent
		for x in curHandler.files:
			nd=root.find_resource(x)
			if nd:
				nodes.append(nd)
			else:
				names.append(x)
		return(nodes,names)
	def quote_flag(self,x):
		return x
class moc(Task.Task):
	color='BLUE'
	run_str='${QT_MOC} ${MOC_FLAGS} ${MOCCPPPATH_ST:INCPATHS} ${MOCDEFINES_ST:DEFINES} ${SRC} ${MOC_ST} ${TGT}'
	def quote_flag(self,x):
		return x
class ui5(Task.Task):
	color='BLUE'
	run_str='${QT_UIC} ${SRC} -o ${TGT}'
	ext_out=['.h']
class ts2qm(Task.Task):
	color='BLUE'
	run_str='${QT_LRELEASE} ${QT_LRELEASE_FLAGS} ${SRC} -qm ${TGT}'
class qm2rcc(Task.Task):
	color='BLUE'
	after='ts2qm'
	def run(self):
		txt='\n'.join(['<file>%s</file>'%k.path_from(self.outputs[0].parent)for k in self.inputs])
		code='<!DOCTYPE RCC><RCC version="1.0">\n<qresource>\n%s\n</qresource>\n</RCC>'%txt
		self.outputs[0].write(code)
def configure(self):
	if'COMPILER_CXX'not in self.env:
		self.fatal('No CXX compiler defined: did you forget to configure compiler_cxx first?')
	self.find_qt5_binaries()
	self.set_qt5_libs_dir()
	self.set_qt5_libs_to_check()
	self.set_qt5_defines()
	self.find_qt5_libraries()
	self.add_qt5_rpath()
	self.simplify_qt5_libs()
	if not has_xml:
		Logs.error('No xml.sax support was found, rcc dependencies will be incomplete!')
	frag='#include <QMap>\nint main(int argc, char **argv) {QMap<int,int> m;return m.keys().size();}\n'
	uses='QT5CORE'
	for flag in[[],'-fPIE','-fPIC','-std=c++11',['-std=c++11','-fPIE'],['-std=c++11','-fPIC']]:
		msg='See if Qt files compile '
		if flag:
			msg+='with %s'%flag
		try:
			self.check(features='qt5 cxx',use=uses,uselib_store='qt5',cxxflags=flag,fragment=frag,msg=msg)
		except self.errors.ConfigurationError:
			pass
		else:
			break
	else:
		self.fatal('Could not build a simple Qt application')
	if Utils.unversioned_sys_platform()=='freebsd':
		frag='#include <QMap>\nint main(int argc, char **argv) {QMap<int,int> m;return m.keys().size();}\n'
		try:
			self.check(features='qt5 cxx cxxprogram',use=uses,fragment=frag,msg='Can we link Qt programs on FreeBSD directly?')
		except self.errors.ConfigurationError:
			self.check(features='qt5 cxx cxxprogram',use=uses,uselib_store='qt5',libpath='/usr/local/lib',fragment=frag,msg='Is /usr/local/lib required?')
@conf
def find_qt5_binaries(self):
	env=self.env
	opt=Options.options
	qtdir=getattr(opt,'qtdir','')
	qtbin=getattr(opt,'qtbin','')
	paths=[]
	if qtdir:
		qtbin=os.path.join(qtdir,'bin')
	if not qtdir:
		qtdir=self.environ.get('QT5_ROOT','')
		qtbin=self.environ.get('QT5_BIN')or os.path.join(qtdir,'bin')
	if qtbin:
		paths=[qtbin]
	if not qtdir:
		paths=self.environ.get('PATH','').split(os.pathsep)
		paths.extend(['/usr/share/qt5/bin','/usr/local/lib/qt5/bin'])
		try:
			lst=Utils.listdir('/usr/local/Trolltech/')
		except OSError:
			pass
		else:
			if lst:
				lst.sort()
				lst.reverse()
				qtdir='/usr/local/Trolltech/%s/'%lst[0]
				qtbin=os.path.join(qtdir,'bin')
				paths.append(qtbin)
	cand=None
	prev_ver=['0','0','0']
	for qmk in('qmake-qt5','qmake5','qmake'):
		try:
			qmake=self.find_program(qmk,path_list=paths)
		except self.errors.ConfigurationError:
			pass
		else:
			try:
				version=self.cmd_and_log(qmake+['-query','QT_VERSION']).strip()
			except self.errors.WafError:
				pass
			else:
				if version:
					new_ver=version.split('.')
					if new_ver[0]=='5'and new_ver>prev_ver:
						cand=qmake
						prev_ver=new_ver
	if not cand:
		try:
			self.find_program('qtchooser')
		except self.errors.ConfigurationError:
			pass
		else:
			cmd=self.env.QTCHOOSER+['-qt=5','-run-tool=qmake']
			try:
				version=self.cmd_and_log(cmd+['-query','QT_VERSION'])
			except self.errors.WafError:
				pass
			else:
				cand=cmd
	if cand:
		self.env.QMAKE=cand
	else:
		self.fatal('Could not find qmake for qt5')
	self.env.QT_HOST_BINS=qtbin=self.cmd_and_log(self.env.QMAKE+['-query','QT_HOST_BINS']).strip()
	paths.insert(0,qtbin)
	def find_bin(lst,var):
		if var in env:
			return
		for f in lst:
			try:
				ret=self.find_program(f,path_list=paths)
			except self.errors.ConfigurationError:
				pass
			else:
				env[var]=ret
				break
	find_bin(['uic-qt5','uic'],'QT_UIC')
	if not env.QT_UIC:
		self.fatal('cannot find the uic compiler for qt5')
	self.start_msg('Checking for uic version')
	uicver=self.cmd_and_log(env.QT_UIC+['-version'],output=Context.BOTH)
	uicver=''.join(uicver).strip()
	uicver=uicver.replace('Qt User Interface Compiler ','').replace('User Interface Compiler for Qt','')
	self.end_msg(uicver)
	if uicver.find(' 3.')!=-1 or uicver.find(' 4.')!=-1:
		self.fatal('this uic compiler is for qt3 or qt4, add uic for qt5 to your path')
	find_bin(['moc-qt5','moc'],'QT_MOC')
	find_bin(['rcc-qt5','rcc'],'QT_RCC')
	find_bin(['lrelease-qt5','lrelease'],'QT_LRELEASE')
	find_bin(['lupdate-qt5','lupdate'],'QT_LUPDATE')
	env.UIC_ST='%s -o %s'
	env.MOC_ST='-o'
	env.ui_PATTERN='ui_%s.h'
	env.QT_LRELEASE_FLAGS=['-silent']
	env.MOCCPPPATH_ST='-I%s'
	env.MOCDEFINES_ST='-D%s'
@conf
def set_qt5_libs_dir(self):
	env=self.env
	qtlibs=getattr(Options.options,'qtlibs',None)or self.environ.get('QT5_LIBDIR')
	if not qtlibs:
		try:
			qtlibs=self.cmd_and_log(env.QMAKE+['-query','QT_INSTALL_LIBS']).strip()
		except Errors.WafError:
			qtdir=self.cmd_and_log(env.QMAKE+['-query','QT_INSTALL_PREFIX']).strip()
			qtlibs=os.path.join(qtdir,'lib')
	self.msg('Found the Qt5 library path',qtlibs)
	env.QTLIBS=qtlibs
@conf
def find_single_qt5_lib(self,name,uselib,qtlibs,qtincludes,force_static):
	env=self.env
	if force_static:
		exts=('.a','.lib')
		prefix='STLIB'
	else:
		exts=('.so','.lib')
		prefix='LIB'
	def lib_names():
		for x in exts:
			for k in('','5')if Utils.is_win32 else['']:
				for p in('lib',''):
					yield(p,name,k,x)
	for tup in lib_names():
		k=''.join(tup)
		path=os.path.join(qtlibs,k)
		if os.path.exists(path):
			if env.DEST_OS=='win32':
				libval=''.join(tup[:-1])
			else:
				libval=name
			env.append_unique(prefix+'_'+uselib,libval)
			env.append_unique('%sPATH_%s'%(prefix,uselib),qtlibs)
			env.append_unique('INCLUDES_'+uselib,qtincludes)
			env.append_unique('INCLUDES_'+uselib,os.path.join(qtincludes,name.replace('Qt5','Qt')))
			return k
	return False
@conf
def find_qt5_libraries(self):
	env=self.env
	qtincludes=self.environ.get('QT5_INCLUDES')or self.cmd_and_log(env.QMAKE+['-query','QT_INSTALL_HEADERS']).strip()
	force_static=self.environ.get('QT5_FORCE_STATIC')
	try:
		if self.environ.get('QT5_XCOMPILE'):
			self.fatal('QT5_XCOMPILE Disables pkg-config detection')
		self.check_cfg(atleast_pkgconfig_version='0.1')
	except self.errors.ConfigurationError:
		for i in self.qt5_vars:
			uselib=i.upper()
			if Utils.unversioned_sys_platform()=='darwin':
				fwk=i.replace('Qt5','Qt')
				frameworkName=fwk+'.framework'
				qtDynamicLib=os.path.join(env.QTLIBS,frameworkName,fwk)
				if os.path.exists(qtDynamicLib):
					env.append_unique('FRAMEWORK_'+uselib,fwk)
					env.append_unique('FRAMEWORKPATH_'+uselib,env.QTLIBS)
					self.msg('Checking for %s'%i,qtDynamicLib,'GREEN')
				else:
					self.msg('Checking for %s'%i,False,'YELLOW')
				env.append_unique('INCLUDES_'+uselib,os.path.join(env.QTLIBS,frameworkName,'Headers'))
			else:
				ret=self.find_single_qt5_lib(i,uselib,env.QTLIBS,qtincludes,force_static)
				if not force_static and not ret:
					ret=self.find_single_qt5_lib(i,uselib,env.QTLIBS,qtincludes,True)
				self.msg('Checking for %s'%i,ret,'GREEN'if ret else'YELLOW')
	else:
		path='%s:%s:%s/pkgconfig:/usr/lib/qt5/lib/pkgconfig:/opt/qt5/lib/pkgconfig:/usr/lib/qt5/lib:/opt/qt5/lib'%(self.environ.get('PKG_CONFIG_PATH',''),env.QTLIBS,env.QTLIBS)
		for i in self.qt5_vars:
			self.check_cfg(package=i,args='--cflags --libs',mandatory=False,force_static=force_static,pkg_config_path=path)
@conf
def simplify_qt5_libs(self):
	env=self.env
	def process_lib(vars_,coreval):
		for d in vars_:
			var=d.upper()
			if var=='QTCORE':
				continue
			value=env['LIBPATH_'+var]
			if value:
				core=env[coreval]
				accu=[]
				for lib in value:
					if lib in core:
						continue
					accu.append(lib)
				env['LIBPATH_'+var]=accu
	process_lib(self.qt5_vars,'LIBPATH_QTCORE')
@conf
def add_qt5_rpath(self):
	env=self.env
	if getattr(Options.options,'want_rpath',False):
		def process_rpath(vars_,coreval):
			for d in vars_:
				var=d.upper()
				value=env['LIBPATH_'+var]
				if value:
					core=env[coreval]
					accu=[]
					for lib in value:
						if var!='QTCORE':
							if lib in core:
								continue
						accu.append('-Wl,--rpath='+lib)
					env['RPATH_'+var]=accu
		process_rpath(self.qt5_vars,'LIBPATH_QTCORE')
@conf
def set_qt5_libs_to_check(self):
	self.qt5_vars=Utils.to_list(getattr(self,'qt5_vars',[]))
	if not self.qt5_vars:
		dirlst=Utils.listdir(self.env.QTLIBS)
		pat=self.env.cxxshlib_PATTERN
		if Utils.is_win32:
			pat=pat.replace('.dll','.lib')
		if self.environ.get('QT5_FORCE_STATIC'):
			pat=self.env.cxxstlib_PATTERN
		if Utils.unversioned_sys_platform()=='darwin':
			pat=r"%s\.framework"
		re_qt=re.compile(pat%'Qt5?(?P<name>\\D+)'+'$')
		for x in dirlst:
			m=re_qt.match(x)
			if m:
				self.qt5_vars.append("Qt5%s"%m.group('name'))
		if not self.qt5_vars:
			self.fatal('cannot find any Qt5 library (%r)'%self.env.QTLIBS)
	qtextralibs=getattr(Options.options,'qtextralibs',None)
	if qtextralibs:
		self.qt5_vars.extend(qtextralibs.split(','))
@conf
def set_qt5_defines(self):
	if sys.platform!='win32':
		return
	for x in self.qt5_vars:
		y=x.replace('Qt5','Qt')[2:].upper()
		self.env.append_unique('DEFINES_%s'%x.upper(),'QT_%s_LIB'%y)
def options(opt):
	opt.add_option('--want-rpath',action='store_true',default=False,dest='want_rpath',help='enable the rpath for qt libraries')
	for i in'qtdir qtbin qtlibs'.split():
		opt.add_option('--'+i,type='string',default='',dest=i)
	opt.add_option('--translate',action='store_true',help='collect translation strings',dest='trans_qt5',default=False)
	opt.add_option('--qtextralibs',type='string',default='',dest='qtextralibs',help='additional qt libraries on the system to add to default ones, comma separated')



#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------
import os

from PyInstaller.utils import misc
from PyInstaller.utils.hooks.qt import pyqt5_library_info, add_qt5_dependencies
from PyInstaller import log as logging

# Ensure PyQt5 is importable before adding info depending on it.
if pyqt5_library_info.version:
    logger = logging.getLogger(__name__)

    hiddenimports, binaries, datas = add_qt5_dependencies(__file__)

    qmldir = pyqt5_library_info.location['Qml2ImportsPath']
    # Per https://github.com/pyinstaller/pyinstaller/pull/3229#issuecomment-359735031,
    # not all PyQt5 installs have QML files. In this case, ``qmldir`` is empty. In
    # addition, the directory may not exist even if ``qmldir`` is not empty, per
    # https://github.com/pyinstaller/pyinstaller/issues/3864.
    if not os.path.exists(qmldir):
        logger.warning('Unable to find Qt5 QML files. QML files not packaged.')
    else:
        qml_rel_dir = ['PyQt5', 'Qt', 'qml']
        datas += [(qmldir, os.path.join(*qml_rel_dir))]
        binaries += [
            # Produce ``/path/to/Qt/Qml/path_to_qml_binary/qml_binary,
            # PyQt5/Qt/Qml/path_to_qml_binary``. When Python 3.4 goes EOL (see
            # PEP 448), this is better written as
            # ``os.path.join(*qml_rel_dir,
            # os.path.dirname(os.path.relpath(f, qmldir))))``.
            (f, os.path.join(*(qml_rel_dir +
                               [os.path.dirname(os.path.relpath(f, qmldir))])))
            for f in misc.dlls_in_subdirs(qmldir)
        ]



#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------


# kinterbasdb
hiddenimports = ['k_exceptions', 'services', 'typeconv_naked',
                 'typeconv_backcompat', 'typeconv_23plus',
                 'typeconv_datetime_stdlib', 'typeconv_datetime_mx',
                 'typeconv_datetime_naked', 'typeconv_fixed_fixedpoint',
                 'typeconv_fixed_stdlib',  'typeconv_text_unicode',
                 'typeconv_util_isinstance', '_kinterbasdb', '_kiservices']



# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2016-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
# -----------------------------------------------------------------------------

"""
text-unidecode:
https://github.com/kmike/text-unidecode/
"""

import os
from PyInstaller.utils.hooks import get_package_paths


package_path = get_package_paths("text_unidecode")
data_bin_path = os.path.join(package_path[1], "data.bin")

if os.path.exists(data_bin_path):
    datas = [(data_bin_path, 'text_unidecode')]



# -----------------------------------------------------------------------------
# Copyright (c) 2005-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
# -----------------------------------------------------------------------------


# This hook was tested with pyexcel 0.5.13:
# https://github.com/pyexcel/pyexcel

hiddenimports = [
    'pyexcel.plugins.renderers.sqlalchemy', 'pyexcel.plugins.renderers.django',
    'pyexcel.plugins.renderers.excel', 'pyexcel.plugins.renderers._texttable',
    'pyexcel.plugins.parsers.excel', 'pyexcel.plugins.parsers.sqlalchemy',
    'pyexcel.plugins.sources.http', 'pyexcel.plugins.sources.file_input',
    'pyexcel.plugins.sources.memory_input',
    'pyexcel.plugins.sources.file_output',
    'pyexcel.plugins.sources.output_to_memory',
    'pyexcel.plugins.sources.pydata.bookdict',
    'pyexcel.plugins.sources.pydata.dictsource',
    'pyexcel.plugins.sources.pydata.arraysource',
    'pyexcel.plugins.sources.pydata.records', 'pyexcel.plugins.sources.django',
    'pyexcel.plugins.sources.sqlalchemy', 'pyexcel.plugins.sources.querysets'
]



#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------
"""
Hook for use with the ttkwidgets package

ttkwidgets provides a set of cross-platform widgets for Tkinter/ttk,
some of which depend on image files in order to function properly.

These images files are all provided in the `ttkwidgets/assets` folder,
which has to be copied by PyInstaller.

This hook has been tested on Ubuntu 18.04 (Python 3.6.8 venv) and
Windows 7 (Python 3.5.4 system-wide).

>>> import tkinter as tk
>>> from ttkwidgets import CheckboxTreeview
>>>
>>> window = tk.Tk()
>>> tree = CheckboxTreeview(window)
>>> tree.insert("", tk.END, "test", text="Hello World!")
>>> tree.insert("test", tk.END, "test2", text="Hello World again!")
>>> tree.insert("test", tk.END, "test3", text="Hello World again again!")
>>> tree.pack()
>>> window.mainloop()
"""


from PyInstaller.utils.hooks import collect_data_files

datas = collect_data_files("ttkwidgets")



# From: https://github.com/pyinstaller/pyinstaller/wiki/Recipe-Multiprocessing

import multiprocessing

class SendeventProcess(multiprocessing.Process):
    def __init__(self, resultQueue):
        self.resultQueue = resultQueue
        multiprocessing.Process.__init__(self)
        self.start()

    def run(self):
        print('SendeventProcess 1')
        self.resultQueue.put((1, 2))
        print('SendeventProcess 2')


if __name__ == '__main__':
    # On Windows calling this function is necessary.
    # On Linux/OSX it does nothing.
    multiprocessing.freeze_support()
    print('main 1')
    resultQueue = multiprocessing.Queue()
    SendeventProcess(resultQueue)
    print('main 2')



#! /usr/bin/env python
# encoding: utf-8
# WARNING! Do not edit! https://waf.io/book/index.html#_obtaining_the_waf_file

from waflib import Utils,Errors
from waflib.Configure import conf
def get_extensions(lst):
	ret=[]
	for x in Utils.to_list(lst):
		if not isinstance(x,str):
			x=x.name
		ret.append(x[x.rfind('.')+1:])
	return ret
def sniff_features(**kw):
	exts=get_extensions(kw.get('source',[]))
	typ=kw['typ']
	feats=[]
	for x in'cxx cpp c++ cc C'.split():
		if x in exts:
			feats.append('cxx')
			break
	if'c'in exts or'vala'in exts or'gs'in exts:
		feats.append('c')
	if's'in exts or'S'in exts:
		feats.append('asm')
	for x in'f f90 F F90 for FOR'.split():
		if x in exts:
			feats.append('fc')
			break
	if'd'in exts:
		feats.append('d')
	if'java'in exts:
		feats.append('java')
		return'java'
	if typ in('program','shlib','stlib'):
		will_link=False
		for x in feats:
			if x in('cxx','d','fc','c','asm'):
				feats.append(x+typ)
				will_link=True
		if not will_link and not kw.get('features',[]):
			raise Errors.WafError('Unable to determine how to link %r, try adding eg: features="c cshlib"?'%kw)
	return feats
def set_features(kw,typ):
	kw['typ']=typ
	kw['features']=Utils.to_list(kw.get('features',[]))+Utils.to_list(sniff_features(**kw))
@conf
def program(bld,*k,**kw):
	set_features(kw,'program')
	return bld(*k,**kw)
@conf
def shlib(bld,*k,**kw):
	set_features(kw,'shlib')
	return bld(*k,**kw)
@conf
def stlib(bld,*k,**kw):
	set_features(kw,'stlib')
	return bld(*k,**kw)
@conf
def objects(bld,*k,**kw):
	set_features(kw,'objects')
	return bld(*k,**kw)



#-----------------------------------------------------------------------------
# Copyright (c) 2005-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------

# Tested with django-babel v0.6.2.
# Hook for https://github.com/python-babel/django-babel

from PyInstaller.utils.hooks import copy_metadata
datas = copy_metadata('django-babel')




#! /usr/bin/env python
# encoding: utf-8
# WARNING! Do not edit! https://waf.io/book/index.html#_obtaining_the_waf_file

import re
from waflib import Build,Context,Errors,Logs,Node,Options,Task,Utils
from waflib.TaskGen import extension,taskgen_method
from waflib.Configure import conf
class valac(Task.Task):
	vars=["VALAC","VALAC_VERSION","VALAFLAGS"]
	ext_out=['.h']
	def run(self):
		cmd=self.env.VALAC+self.env.VALAFLAGS
		resources=getattr(self,'vala_exclude',[])
		cmd.extend([a.abspath()for a in self.inputs if a not in resources])
		ret=self.exec_command(cmd,cwd=self.vala_dir_node.abspath())
		if ret:
			return ret
		if self.generator.dump_deps_node:
			self.generator.dump_deps_node.write('\n'.join(self.generator.packages))
		return ret
@taskgen_method
def init_vala_task(self):
	self.profile=getattr(self,'profile','gobject')
	self.packages=packages=Utils.to_list(getattr(self,'packages',[]))
	self.use=Utils.to_list(getattr(self,'use',[]))
	if packages and not self.use:
		self.use=packages[:]
	if self.profile=='gobject':
		if not'GOBJECT'in self.use:
			self.use.append('GOBJECT')
	def addflags(flags):
		self.env.append_value('VALAFLAGS',flags)
	if self.profile:
		addflags('--profile=%s'%self.profile)
	valatask=self.valatask
	if hasattr(self,'vala_dir'):
		if isinstance(self.vala_dir,str):
			valatask.vala_dir_node=self.path.get_bld().make_node(self.vala_dir)
			try:
				valatask.vala_dir_node.mkdir()
			except OSError:
				raise self.bld.fatal('Cannot create the vala dir %r'%valatask.vala_dir_node)
		else:
			valatask.vala_dir_node=self.vala_dir
	else:
		valatask.vala_dir_node=self.path.get_bld()
	addflags('--directory=%s'%valatask.vala_dir_node.abspath())
	if hasattr(self,'thread'):
		if self.profile=='gobject':
			if not'GTHREAD'in self.use:
				self.use.append('GTHREAD')
		else:
			Logs.warn('Profile %s means no threading support',self.profile)
			self.thread=False
		if self.thread:
			addflags('--thread')
	self.is_lib='cprogram'not in self.features
	if self.is_lib:
		addflags('--library=%s'%self.target)
		h_node=valatask.vala_dir_node.find_or_declare('%s.h'%self.target)
		valatask.outputs.append(h_node)
		addflags('--header=%s'%h_node.name)
		valatask.outputs.append(valatask.vala_dir_node.find_or_declare('%s.vapi'%self.target))
		if getattr(self,'gir',None):
			gir_node=valatask.vala_dir_node.find_or_declare('%s.gir'%self.gir)
			addflags('--gir=%s'%gir_node.name)
			valatask.outputs.append(gir_node)
	self.vala_target_glib=getattr(self,'vala_target_glib',getattr(Options.options,'vala_target_glib',None))
	if self.vala_target_glib:
		addflags('--target-glib=%s'%self.vala_target_glib)
	addflags(['--define=%s'%x for x in Utils.to_list(getattr(self,'vala_defines',[]))])
	packages_private=Utils.to_list(getattr(self,'packages_private',[]))
	addflags(['--pkg=%s'%x for x in packages_private])
	def _get_api_version():
		api_version='1.0'
		if hasattr(Context.g_module,'API_VERSION'):
			version=Context.g_module.API_VERSION.split(".")
			if version[0]=="0":
				api_version="0."+version[1]
			else:
				api_version=version[0]+".0"
		return api_version
	self.includes=Utils.to_list(getattr(self,'includes',[]))
	valatask.install_path=getattr(self,'install_path','')
	valatask.vapi_path=getattr(self,'vapi_path','${DATAROOTDIR}/vala/vapi')
	valatask.pkg_name=getattr(self,'pkg_name',self.env.PACKAGE)
	valatask.header_path=getattr(self,'header_path','${INCLUDEDIR}/%s-%s'%(valatask.pkg_name,_get_api_version()))
	valatask.install_binding=getattr(self,'install_binding',True)
	self.vapi_dirs=vapi_dirs=Utils.to_list(getattr(self,'vapi_dirs',[]))
	if hasattr(self,'use'):
		local_packages=Utils.to_list(self.use)[:]
		seen=[]
		while len(local_packages)>0:
			package=local_packages.pop()
			if package in seen:
				continue
			seen.append(package)
			try:
				package_obj=self.bld.get_tgen_by_name(package)
			except Errors.WafError:
				continue
			package_obj.post()
			package_name=package_obj.target
			task=getattr(package_obj,'valatask',None)
			if task:
				for output in task.outputs:
					if output.name==package_name+".vapi":
						valatask.set_run_after(task)
						if package_name not in packages:
							packages.append(package_name)
						if output.parent not in vapi_dirs:
							vapi_dirs.append(output.parent)
						if output.parent not in self.includes:
							self.includes.append(output.parent)
			if hasattr(package_obj,'use'):
				lst=self.to_list(package_obj.use)
				lst.reverse()
				local_packages=[pkg for pkg in lst if pkg not in seen]+local_packages
	addflags(['--pkg=%s'%p for p in packages])
	for vapi_dir in vapi_dirs:
		if isinstance(vapi_dir,Node.Node):
			v_node=vapi_dir
		else:
			v_node=self.path.find_dir(vapi_dir)
		if not v_node:
			Logs.warn('Unable to locate Vala API directory: %r',vapi_dir)
		else:
			addflags('--vapidir=%s'%v_node.abspath())
	self.dump_deps_node=None
	if self.is_lib and self.packages:
		self.dump_deps_node=valatask.vala_dir_node.find_or_declare('%s.deps'%self.target)
		valatask.outputs.append(self.dump_deps_node)
	if self.is_lib and valatask.install_binding:
		headers_list=[o for o in valatask.outputs if o.suffix()==".h"]
		if headers_list:
			self.install_vheader=self.add_install_files(install_to=valatask.header_path,install_from=headers_list)
		vapi_list=[o for o in valatask.outputs if(o.suffix()in(".vapi",".deps"))]
		if vapi_list:
			self.install_vapi=self.add_install_files(install_to=valatask.vapi_path,install_from=vapi_list)
		gir_list=[o for o in valatask.outputs if o.suffix()=='.gir']
		if gir_list:
			self.install_gir=self.add_install_files(install_to=getattr(self,'gir_path','${DATAROOTDIR}/gir-1.0'),install_from=gir_list)
	if hasattr(self,'vala_resources'):
		nodes=self.to_nodes(self.vala_resources)
		valatask.vala_exclude=getattr(valatask,'vala_exclude',[])+nodes
		valatask.inputs.extend(nodes)
		for x in nodes:
			addflags(['--gresources',x.abspath()])
@extension('.vala','.gs')
def vala_file(self,node):
	try:
		valatask=self.valatask
	except AttributeError:
		valatask=self.valatask=self.create_task('valac')
		self.init_vala_task()
	valatask.inputs.append(node)
	name=node.name[:node.name.rfind('.')]+'.c'
	c_node=valatask.vala_dir_node.find_or_declare(name)
	valatask.outputs.append(c_node)
	self.source.append(c_node)
@extension('.vapi')
def vapi_file(self,node):
	try:
		valatask=self.valatask
	except AttributeError:
		valatask=self.valatask=self.create_task('valac')
		self.init_vala_task()
	valatask.inputs.append(node)
@conf
def find_valac(self,valac_name,min_version):
	valac=self.find_program(valac_name,var='VALAC')
	try:
		output=self.cmd_and_log(valac+['--version'])
	except Errors.WafError:
		valac_version=None
	else:
		ver=re.search(r'\d+.\d+.\d+',output).group().split('.')
		valac_version=tuple([int(x)for x in ver])
	self.msg('Checking for %s version >= %r'%(valac_name,min_version),valac_version,valac_version and valac_version>=min_version)
	if valac and valac_version<min_version:
		self.fatal("%s version %r is too old, need >= %r"%(valac_name,valac_version,min_version))
	self.env.VALAC_VERSION=valac_version
	return valac
@conf
def check_vala(self,min_version=(0,8,0),branch=None):
	if self.env.VALA_MINVER:
		min_version=self.env.VALA_MINVER
	if self.env.VALA_MINVER_BRANCH:
		branch=self.env.VALA_MINVER_BRANCH
	if not branch:
		branch=min_version[:2]
	try:
		find_valac(self,'valac-%d.%d'%(branch[0],branch[1]),min_version)
	except self.errors.ConfigurationError:
		find_valac(self,'valac',min_version)
@conf
def check_vala_deps(self):
	if not self.env.HAVE_GOBJECT:
		pkg_args={'package':'gobject-2.0','uselib_store':'GOBJECT','args':'--cflags --libs'}
		if getattr(Options.options,'vala_target_glib',None):
			pkg_args['atleast_version']=Options.options.vala_target_glib
		self.check_cfg(**pkg_args)
	if not self.env.HAVE_GTHREAD:
		pkg_args={'package':'gthread-2.0','uselib_store':'GTHREAD','args':'--cflags --libs'}
		if getattr(Options.options,'vala_target_glib',None):
			pkg_args['atleast_version']=Options.options.vala_target_glib
		self.check_cfg(**pkg_args)
def configure(self):
	self.load('gnu_dirs')
	self.check_vala_deps()
	self.check_vala()
	self.add_os_flags('VALAFLAGS')
	self.env.append_unique('VALAFLAGS',['-C'])
def options(opt):
	opt.load('gnu_dirs')
	valaopts=opt.add_option_group('Vala Compiler Options')
	valaopts.add_option('--vala-target-glib',default=None,dest='vala_target_glib',metavar='MAJOR.MINOR',help='Target version of glib for Vala GObject code generation')



#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------


import os
import sys


try:
    FileNotFoundError
except NameError:
    # FileNotFoundError is new in Python 3.0
    # NB: Aliasing IOError is not a full emulation of FileNotFoundError,
    # but far enough for this usecase, where the whole frozen program
    # terminates when this exception occurs.
    FileNotFoundError = IOError

tcldir = os.path.join(sys._MEIPASS, 'tcl')
tkdir = os.path.join(sys._MEIPASS, 'tk')

if not os.path.isdir(tcldir):
    raise FileNotFoundError('Tcl data directory "%s" not found.' % (tcldir))
if not os.path.isdir(tkdir):
    raise FileNotFoundError('Tk data directory "%s" not found.' % (tkdir))

# Notify "tkinter" of such directories.
os.environ["TCL_LIBRARY"] = tcldir
os.environ["TK_LIBRARY"] = tkdir



#-----------------------------------------------------------------------------
# Copyright (c) 2005-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------

import os
from PyInstaller.utils.hooks import collect_system_data_files
from PyInstaller.utils.hooks.qt import pyside2_library_info, get_qt_binaries
from PyInstaller.compat import is_win

hiddenimports = ['shiboken2']

# Collect the ``qt.conf`` file.
if is_win:
    target_qt_conf_dir = os.curdir
else:
    target_qt_conf_dir = 'PySide2'

datas = [x for x in
         collect_system_data_files(pyside2_library_info.location['PrefixPath'],
                                   target_qt_conf_dir)
         if os.path.basename(x[0]) == 'qt.conf']

# Collect required Qt binaries.
binaries = get_qt_binaries(pyside2_library_info)



#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------


"""
The matplotlib.numerix package sneaks these imports in under the radar:
"""


hiddenimports = [
    'fft',
    'linear_algebra',
    'random_array',
    'ma',
    'mlab',
]

